==> jc-1.4.0.tar.gz: polyglot/frontend/PrettyPrintPass.h <==
// public class polyglot.frontend.PrettyPrintPass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 2bdfb73a6944747b polyglot_frontend_PrettyPrintPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_PrettyPrintPass_H_
#define _JC_polyglot_frontend_PrettyPrintPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_visit_PrettyPrinter$object;

// Typedefs
typedef struct _jc_polyglot_frontend_PrettyPrintPass$sub_refs	_jc_polyglot_frontend_PrettyPrintPass$sub_refs;
typedef struct _jc_polyglot_frontend_PrettyPrintPass$sub_nonrefs	_jc_polyglot_frontend_PrettyPrintPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_PrettyPrintPass$refs	_jc_polyglot_frontend_PrettyPrintPass$refs;
typedef struct _jc_polyglot_frontend_PrettyPrintPass$nonrefs	_jc_polyglot_frontend_PrettyPrintPass$nonrefs;
typedef struct _jc_polyglot_frontend_PrettyPrintPass$object	_jc_polyglot_frontend_PrettyPrintPass$object;

typedef const struct _jc_polyglot_frontend_PrettyPrintPass$vmethods	_jc_polyglot_frontend_PrettyPrintPass$vmethods;
typedef const struct _jc_polyglot_frontend_PrettyPrintPass$vtable	_jc_polyglot_frontend_PrettyPrintPass$vtable;
typedef const struct _jc_polyglot_frontend_PrettyPrintPass$vtype	_jc_polyglot_frontend_PrettyPrintPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_PrettyPrintPass$method$_init$f01ec75defc27af0(_jc_env *, struct _jc_polyglot_frontend_PrettyPrintPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *);

// Virtual methods
extern jboolean _jc_polyglot_frontend_PrettyPrintPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_PrettyPrintPass$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_PrettyPrintPass$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_polyglot_frontend_PrettyPrintPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_PrettyPrintPass$object *);
};

// Vtable
struct _jc_polyglot_frontend_PrettyPrintPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_PrettyPrintPass$vmethods	polyglot_frontend_PrettyPrintPass;
};

// Vtype
struct _jc_polyglot_frontend_PrettyPrintPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_PrettyPrintPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_PrettyPrintPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_polyglot_visit_PrettyPrinter$object	*pp;
	struct _jc_polyglot_util_CodeWriter$object	*w;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_PrettyPrintPass$refs {
    _jc_polyglot_frontend_PrettyPrintPass$sub_refs	polyglot_frontend_PrettyPrintPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_PrettyPrintPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_PrettyPrintPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_PrettyPrintPass$sub_nonrefs	polyglot_frontend_PrettyPrintPass;
};

// Object instance structure
struct _jc_polyglot_frontend_PrettyPrintPass$object {
	_jc_polyglot_frontend_PrettyPrintPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_PrettyPrintPass$vtype	*vtype;
	_jc_polyglot_frontend_PrettyPrintPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_PrettyPrintPass$vtype _jc_polyglot_frontend_PrettyPrintPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_PrettyPrintPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_PrettyPrintPass$class_object;

#endif	/* _JC_polyglot_frontend_PrettyPrintPass_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/PrettyPrintPass.h <==
// public class polyglot.frontend.PrettyPrintPass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 2bdfb73a6944747b polyglot_frontend_PrettyPrintPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_PrettyPrintPass_H_
#define _JC_polyglot_frontend_PrettyPrintPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_visit_PrettyPrinter$object;

// Typedefs
typedef struct _jc_polyglot_frontend_PrettyPrintPass$sub_refs	_jc_polyglot_frontend_PrettyPrintPass$sub_refs;
typedef struct _jc_polyglot_frontend_PrettyPrintPass$sub_nonrefs	_jc_polyglot_frontend_PrettyPrintPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_PrettyPrintPass$refs	_jc_polyglot_frontend_PrettyPrintPass$refs;
typedef struct _jc_polyglot_frontend_PrettyPrintPass$nonrefs	_jc_polyglot_frontend_PrettyPrintPass$nonrefs;
typedef struct _jc_polyglot_frontend_PrettyPrintPass$object	_jc_polyglot_frontend_PrettyPrintPass$object;

typedef const struct _jc_polyglot_frontend_PrettyPrintPass$vmethods	_jc_polyglot_frontend_PrettyPrintPass$vmethods;
typedef const struct _jc_polyglot_frontend_PrettyPrintPass$vtable	_jc_polyglot_frontend_PrettyPrintPass$vtable;
typedef const struct _jc_polyglot_frontend_PrettyPrintPass$vtype	_jc_polyglot_frontend_PrettyPrintPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_PrettyPrintPass$method$_init$f01ec75defc27af0(_jc_env *, struct _jc_polyglot_frontend_PrettyPrintPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_frontend_PrettyPrintPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_PrettyPrintPass$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_PrettyPrintPass$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_polyglot_frontend_PrettyPrintPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_PrettyPrintPass$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_PrettyPrintPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_PrettyPrintPass$vmethods	polyglot_frontend_PrettyPrintPass;
};

// Vtype
struct _jc_polyglot_frontend_PrettyPrintPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_PrettyPrintPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_PrettyPrintPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_polyglot_visit_PrettyPrinter$object	*pp;
	struct _jc_polyglot_util_CodeWriter$object	*w;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_PrettyPrintPass$refs {
    _jc_polyglot_frontend_PrettyPrintPass$sub_refs	polyglot_frontend_PrettyPrintPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_PrettyPrintPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_PrettyPrintPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_PrettyPrintPass$sub_nonrefs	polyglot_frontend_PrettyPrintPass;
};

// Object instance structure
struct _jc_polyglot_frontend_PrettyPrintPass$object {
	_jc_polyglot_frontend_PrettyPrintPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_PrettyPrintPass$vtype	*vtype;
	_jc_polyglot_frontend_PrettyPrintPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_PrettyPrintPass$vtype _jc_polyglot_frontend_PrettyPrintPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_PrettyPrintPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_PrettyPrintPass$class_object;

#endif	/* _JC_polyglot_frontend_PrettyPrintPass_H_ */
